Welcome to LLM Assistant's documentation!
==========================================

Collection of simple LLM applications

Start here
================
.. toctree::
   :maxdepth: 1

   getting-started


How-to guides
=============

.. toctree::
   :maxdepth: 1

   how-to/setup-assistant
   how-to/run-a-prompt
   how-to/sync-and-push-prompts


Reference guides
================

.. toctree::
   :maxdepth: 1

   api-reference


Explanation
===========

.. toctree::
   :maxdepth: 2

   design-and-architecture


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
